@@ -41,27 +41,42 @@ struct duo_config {
     int  local_ip_fallback;
     int  https_timeout;
     int  send_gecos;
+    int  gecos_parsed;
 };
 
 void duo_config_default(struct duo_config *cfg);
 
 int duo_set_boolean_option(const char *val);
 
-int duo_common_ini_handler(struct duo_config *cfg, const char *section, 
-    const char *name, const char*val);
+int duo_common_ini_handler(
+    struct duo_config *cfg,
+    const char *section,
+    const char *name,
+    const char *val
+);
+
+/* Clean up config memory. */
+void close_config(struct duo_config *cfg);
 
 int duo_check_groups(struct passwd *pw, char **groups, int groups_cnt);
 
-void duo_log(int priority, const char*msg, const char *user, const char *ip,
-             const char *err);
+void duo_log(
+    int priority,
+    const char *msg,
+    const char *user,
+    const char *ip,
+    const char *err
+);
 
 void duo_syslog(int priority, const char *fmt, ...);
 
-const char *
-duo_resolve_name(const char *hostname);
+const char *duo_resolve_name(const char *hostname);
 
-const char *
-duo_local_ip();
+const char *duo_local_ip();
 
+char *duo_split_at(char *s, char delimiter, unsigned int position);
+
+/* Free and zero out memory */
+void duo_zero_free(void *ptr, size_t size);
 
 #endif
